
.. _`Exceptions`:

Exceptions
----------

.. automodule:: pywbem.exceptions

.. autoclass:: pywbem.Error
   :members:

.. autoclass:: pywbem.ConnectionError
   :members:

.. autoclass:: pywbem.AuthError
   :members:

.. autoclass:: pywbem.HTTPError
   :members:

.. autoclass:: pywbem.TimeoutError
   :members:

.. autoclass:: pywbem.ParseError
   :members:

.. autoclass:: pywbem.CIMError
   :members:
